# Translation

The `Translation` task translates documents into a target language.

## Usage

```python
--8<-- "sieves/tests/docs/test_task_usage.py:translation-usage"
```

---

::: sieves.tasks.predictive.translation.core
::: sieves.tasks.predictive.translation.bridges
